@@ -1,9 +1,16 @@
-import rowingdata
+from __future__ import absolute_import
+from __future__ import print_function
+
+try:
+    from . import rowingdata
+except (ValueError,ImportError):
+    import rowingdata
 
 import os
 
 def checkfile(f2, verbose=False):
     fileformat = rowingdata.get_file_type(f2)
+    summary = 'a'
     notread = 1
     if verbose:
         print(fileformat)
@@ -37,6 +44,10 @@ def checkfile(f2, verbose=False):
         # handle Quiske
         if (fileformat == 'quiske'):
             row = rowingdata.QuiskeParser(f2)
+
+        # handle RitmoTime
+        if (fileformat == 'ritmotime'):
+            row = rowingdata.RitmoTimeParser(f2)
             
         # handle TCX no HR
         if (fileformat == 'tcxnohr'):
@@ -73,6 +84,9 @@ def checkfile(f2, verbose=False):
         # handle speed coach GPS 2
         if (fileformat == 'speedcoach2'):
             row = rowingdata.SpeedCoach2Parser(f2)
+            summary = row.allstats()
+            v = rowingdata.get_empower_firmware(f2)
+            rig = rowingdata.get_empower_rigging(f2)
 
         if (fileformat == 'rowperfect3'):
             row = rowingdata.RowPerfectParser(f2)
@@ -93,6 +107,15 @@ def checkfile(f2, verbose=False):
             os.remove(f2 + 'o.csv')
             notread = 0
 
+        # handle Humon
+        if (fileformat == 'humon'):
+            row = rowingdata.HumonParser(f2)
+            row.write_csv(f2 + 'o.csv')
+            row = rowingdata.rowingdata(csvfile=f2 + 'o.csv')
+            os.remove(f2 + 'o.csv')
+            notread = 0
+
+
         # handle workout log (no stroke data)
         if (fileformat == 'c2log'):
             return 0
@@ -109,21 +132,24 @@ def checkfile(f2, verbose=False):
     distmax = row.df['cum_dist'].max()
     timemax = row.df['TimeStamp (sec)'].max() - row.df['TimeStamp (sec)'].min()
     nrintervals = len(row.df[' lapIdx'].unique())
-
+    mintime = row.df['TimeStamp (sec)'].min()
+    maxtime = row.df['TimeStamp (sec)'].max()
     if verbose:
-        print("nr lines", row.number_of_rows)
-        print("data ", row.rowdatetime)
-        print("dist ", distmax)
-        print("Time ", timemax)
-        print("Nr intervals ", nrintervals)
+        print(("nr lines", row.number_of_rows))
+        print(("data ", row.rowdatetime))
+        print(("dist ", distmax))
+        print(("Time ", timemax))
+        print(("Nr intervals ", nrintervals))
+        print(("Min time ",mintime))
+        print(("Max time ",maxtime))
 
     res = row.intervalstats_values()
     int1time = res[0][0]
     int1dist = res[1][0]
 
     if verbose:
-        print("Interval 1 time ", int1time)
-        print("Interval 1 dist ", int1dist)
+        print(("Interval 1 time ", int1time))
+        print(("Interval 1 dist ", int1dist))
 
     y = row.rowdatetime.year
     m = row.rowdatetime.month
@@ -148,6 +174,7 @@ def checkfile(f2, verbose=False):
         'lap 1 time': int(int1time),
         'lap 1 dist': int(int1dist),
         'timezone': tz,
+        'summary':summary,
     }
 
     return results
